@@ -746,6 +746,7 @@ class Project(AL_Node, Watchable):
             project = self,
             editor = self.author,
         )
+        logging.debug("Project '%s': created config %s" % (self, config))
         self.state = State.CONFIG_CREATED
         return config
 
@@ -1471,7 +1472,7 @@ class UserProfile(RichUserProfile):
     """
     Base user profile class for ``django-projector``.
     Would be abstract if ``AUTH_PROFILE_MODULE`` is not set or doesn't equal
-    with ``projector.UserProfile``.
+    to ``projector.UserProfile``.
     """
     activation_token = models.CharField(_('activation token'), max_length=32,
         editable=False)
